@@ -1,5 +1,9 @@
 package DataFlow::Item;
 
+BEGIN {
+    $DataFlow::Item::VERSION = '0.91.00_01';
+}
+
 use Moose;
 use DataFlow::Meta;
 
@@ -13,6 +17,8 @@ has data => (
     isa => 'Any',
 );
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -23,6 +29,10 @@ __END__
 
 DataFlow::Item - A DataFlow item with the associated metadata
 
+=head1 VERSION
+
+version 0.91.00_01
+
 =head1 SYNOPSIS
 
     use DataFlow::Item;
