@@ -1,6 +1,10 @@
 
 package DataFlow::Node::Debug;
 
+BEGIN {
+    $DataFlow::Node::Debug::VERSION = '0.91.00_01';
+}
+
 use Moose;
 extends 'DataFlow::Node';
 
@@ -16,5 +20,6 @@ has '+process_item' => (
     }
 );
 
-1;
+__PACKAGE__->meta->make_immutable;
 
+1;
