@@ -1,6 +1,10 @@
 
 package DataFlow::Node::Encoding;
 
+BEGIN {
+    $DataFlow::Node::Encoding::VERSION = '0.91.00_01';
+}
+
 use Moose;
 extends 'DataFlow::Node';
 
@@ -34,5 +38,6 @@ has '+process_item' => (
     },
 );
 
-1;
+__PACKAGE__->meta->make_immutable;
 
+1;
