@@ -1,6 +1,10 @@
 
 package DataFlow::Node::MultiPageURLGenerator;
 
+BEGIN {
+    $DataFlow::Node::MultiPageURLGenerator::VERSION = '0.91.00_01';
+}
+
 use Moose;
 extends 'DataFlow::Node';
 
@@ -80,5 +84,6 @@ has '+process_item' => (
     },
 );
 
-1;
+__PACKAGE__->meta->make_immutable;
 
+1;
