@@ -1,6 +1,10 @@
 
 package DataFlow::Node::URLRetriever;
 
+BEGIN {
+    $DataFlow::Node::URLRetriever::VERSION = '0.91.00_01';
+}
+
 use Moose;
 extends 'DataFlow::Node';
 
@@ -36,5 +40,6 @@ has '+process_item' => (
     },
 );
 
-1;
+__PACKAGE__->meta->make_immutable;
 
+1;
